####################################################################################
# include files

source notebook.tcl
source editorglobals.tcl

source groupmenu.tcl
source instancemenu.tcl

source spheremenu.tcl
source conemenu.tcl
source cylindermenu.tcl
source torusmenu.tcl
source cyclidemenu.tcl

####################################################################################

# ------------------------------------------------------------------------------
#  Frame: .editor
#
#  Methods:
#     - Editor:Create
#     - Editor:Init
#     - Editor:InitSurface
#     - Editor:AddSurface
#     - Editor:Clear
#     - Editor:Destroy
#     - Editor:SetParameterValues
#     - Editor:EditNode
#
#     - Editor:LeftDown   - this is for changing entry focus
#
#  Variables:
#     - editorHeight
#     - editorWidth
#     - notebookFrame, defaultFrame, sphereFrame, groupFrame, etc
#     - editNodeName      - slide name
#     - editNodeUserName  - user given name
#     - editNodeType
#     - editStandAlone
#
#     - surfaceList, surfaceValue, surfaceHelp
#
#  Variables set in other classes
#     - solidValue, solidList, solidHelp
#     - shadingValue, shadingList, shadingHelp
#     - lodValue, lodList, lodHelp
#     - ribbeginValue, ribbeginList, ribbeginHelp
#     - ribendValue, ribendList, ribendHelp
#
# ------------------------------------------------------------------------------

proc Editor:Create { } {
    global editorHeight editorWidth paleOrange progress progressText guiSystem

    Editor:Init

    set w .editor
    toplevel $w -width $editorWidth -height $editorHeight
    wm title    $w "Editor"

    if { $guiSystem == "irix" } {
	wm geometry $w +120+547
    } elseif { $guiSystem == "nt" } {
	wm geometry $w +120+545
    } else {
	puts "ERROR Editor:Create: System not IRIX or NT"
	exit
    }	

    wm minsize  $w  420 420
    wm maxsize  $w  420 420
    wm protocol $w WM_DELETE_WINDOW {set foo 1}


    bind .editor <Button-1> {Editor:LeftDown}

    #########################################
    # Create Label
    incr progress
    set progressText "Creating name frame ..."

    global editorNameFrame editNodeUserName
    set editorNameFrame $w.label

    frame $editorNameFrame
    place $editorNameFrame -x 0 -y 0 -anchor nw -width $editorWidth -height 38

    Entry $editorNameFrame.name -textvariable editNodeUserName -font {Helvetica -20} \
	    -background white -selectbackground $paleOrange \
	    -command "Editor:EntryLooseFocus"
    bind $editorNameFrame.name <Button-1>   "Editor:EntryHasFocus $editorNameFrame.name"

    place $editorNameFrame.name -x 10 -y 5 -anchor nw \
	    -width [expr $editorWidth-20] -height 28

#    Label $editorNameFrame.label -borderwidth 1 -font {Helvetica 14 bold} \
#	    -text "INSTANCE:" 
#    Entry $editorNameFrame.name -textvariable editorLabel -font {Helvetica -20} \
#	    -background white -width 26

    #########################################
    # Create Default page
    incr progress
    set progressText "Creating default frame ..."

    global defaultFrame
    set defaultFrame $w.default

    frame $defaultFrame
    place $defaultFrame -x 0 -y 0 -anchor nw -width $editorWidth -height $editorHeight

    label $defaultFrame.label -borderwidth 1 -font {Helvetica 24 bold} -text "" 
    place $defaultFrame.label -x 210 -y 210 -anchor center

    #########################################
    # Create Notebook
    incr progress
    set progressText "Creating notebook..."

    global notebookFrame notebookStart notebookHeight
    set notebookFrame $w.notebook
    frame $notebookFrame -width $editorWidth -height $notebookHeight
    place $notebookFrame -x 0 -y $notebookStart -anchor nw
    raise $editorNameFrame

    #########################################
    # Create not page
    incr progress
    set progressText "Creating not frame ..."

    global notFrame
    set notFrame $notebookFrame.not

    frame $notFrame
    place $notFrame -x 0 -y 0 -anchor nw -width $editorWidth -height $editorHeight

    Label $notFrame.label -borderwidth 1 -font {Helvetica 11 bold} \
	    -text "not yet implemented" 
    place $notFrame.label -x 225 -y 210 -anchor center

    #########################################
    # Create GROUP page
    incr progress
    set progressText "Creating group frame ..."

    global groupFrame
    set groupFrame $notebookFrame.group
    Notebook:create $groupFrame -name " " -pages {Instances Options} -pad 10 \
	    -width 400 -height 400
    place $groupFrame -x 0 -y 0 -anchor nw -width $editorWidth -height $notebookHeight

    # Add Sphere Widgets
    GroupMenu:Create $groupFrame 

    #########################################
    # Create INSTANCE page
    incr progress
    set progressText "Creating instance frame ..."

    global instanceFrame
    set instanceFrame $notebookFrame.instance

    Notebook:create $instanceFrame -name " " -pages {Transforms Options} -pad 10 \
	    -width 400 -height 400
    place $instanceFrame -x 0 -y 0 -anchor nw -width $editorWidth -height $notebookHeight

    # Add Sphere Widgets
    InstanceMenu:Create $instanceFrame 

    #########################################
    # Create SPHERE page
    incr progress
    set progressText "Creating sphere frame ..."

    global sphereFrame
    set sphereFrame $notebookFrame.sphere 
    Notebook:create $sphereFrame -name " " -pages {Geometry Options} -pad 10 \
	    -width 400 -height 400
    place $sphereFrame -x 0 -y 0 -anchor nw -width $editorWidth -height $notebookHeight

    # Add Sphere Widgets
    SphereMenu:Create  $sphereFrame 

    #########################################
    # Create CONE page
    incr progress
    set progressText "Creating cone frame ..."

    global coneFrame
    set coneFrame $notebookFrame.cone 
    Notebook:create $coneFrame -name " " -pages {Geometry Options} -pad 10 \
	    -width 400 -height 400
    place $coneFrame -x 0 -y 0 -anchor nw -width $editorWidth -height $notebookHeight

    # Add Cone Widgets
    ConeMenu:Create  $coneFrame 

    #########################################
    # Create CYLINDER page
    incr progress
    set progressText "Creating cylinder frame ..."

    global cylinderFrame
    set cylinderFrame $notebookFrame.cylinder 
    Notebook:create $cylinderFrame -name " " -pages {Geometry Options} -pad 10 \
	    -width 400 -height 400
    place $cylinderFrame -x 0 -y 0 -anchor nw -width $editorWidth -height $notebookHeight

    # Add Cylinder Widgets
    CylinderMenu:Create  $cylinderFrame 

    #########################################
    # Create TORUS page
    incr progress
    set progressText "Creating torus frame ..."

    global torusFrame
    set torusFrame $notebookFrame.torus 
    Notebook:create $torusFrame -name " " -pages {Geometry Options} -pad 10 \
	    -width 400 -height 400
    place $torusFrame -x 0 -y 0 -anchor nw -width $editorWidth -height $notebookHeight

    # Add Torus Widgets
    TorusMenu:Create  $torusFrame 

    #########################################
    # Create CYCLIDE page
    incr progress
    set progressText "Creating cyclide frame ..."

    global cyclideFrame
    set cyclideFrame $notebookFrame.cyclide 
    Notebook:create $cyclideFrame -name " " -pages {Geometry Options} -pad 10 \
	    -width 400 -height 400
    place $cyclideFrame -x 0 -y 0 -anchor nw -width $editorWidth -height $notebookHeight

    # Add Cyclide Widgets
    CyclideMenu:Create  $cyclideFrame 

    #########################################
    incr progress
    set progressText "Raising frame..."

#    raise $groupFrame 
#    raise $instanceFrame
#    raise $sphereFrame
#    raise $coneFrame
#    raise $cylinderFrame
#    raise $torusFrame
#    raise $cyclideFrame
    raise $defaultFrame
}

proc Editor:Init { } {
    global setEntryValue editorEntryHasFocus editorKeepFocus

    set setEntryValue       0
    set editorEntryHasFocus 0
    set editorKeepFocus     0


    global editStandAlone editNodeName editNodeUserName editNodeType 
    global editorHeight editorWidth
    global notebookStart notebookHeight

    set editStandAlone       0
    set editNodeName      none
    set editNodeUserName  none
    set editNodeType      none
    set editorWidth    420
    set editorHeight   420
    set notebookStart   34
    set notebookHeight [expr $editorHeight - $notebookStart]

    Editor:InitSurface
}

proc Editor:InitSurface { } {
    global surfaceValue surfaceList surfaceHelp

    set surfaceValue inherit
    set surfaceList {inherit}
    set surfaceHelp "This option specifies the surface to apply to this object"
}

proc Editor:AddSurface { surfaceName } {
    global surfaceList sphereOptionsFrame groupOptionsFrame instanceOptionsFrame

    lappend surfaceList $surfaceName

    $sphereOptionsFrame.surface.menu configure -values $surfaceList
    $sphereOptionsFrame.surface.menu configure -height [expr [llength $surfaceList]]

    $groupOptionsFrame.surface.menu configure -values $surfaceList
    $groupOptionsFrame.surface.menu configure -height [expr [llength $surfaceList]]

    $instanceOptionsFrame.surface.menu configure -values $surfaceList
    $instanceOptionsFrame.surface.menu configure -height [expr [llength $surfaceList]]
}

proc Editor:Clear { } {
    global defaultFrame surfaceList

    raise $defaultFrame
    wm title .editor "Editor"
    set surfaceList {inherit}
}

proc Editor:Destroy { } {

    destroy .editor
}

proc Editor:SetParameterValues { type values } {

    if { ($type == "Group") || ($type == "Instance") } {

	[subst $type]Menu:SetParameterValues $values

    } else {

	GeomMenu:SetParameterValues $type $values
    }
}

proc Editor:EditNode { nodeName userName type } {
    global editNodeName editNodeUserName editNodeType defaultFrame notFrame

    if { $type == "instanceCircle" } {
	set type "instance"
    }

    set editNodeName     $nodeName
    set editNodeUserName $userName
    set editNodeType     $type

    global [subst $type]Frame editorNameFrame notebookFrame

    if { ($type == "group") || ($type == "instance") || \
	    ($type == "sphere") || ($type == "cone") || ($type == "cylinder") || \
	    ($type == "torus") || ($type == "cyclide") } {

	raise $editorNameFrame
	raise $notebookFrame
	raise [expr $[subst $type]Frame]

	set upperType [string index $type 0]
	set lowerType [string trimleft $type $upperType]
	set upperType [string toupper $upperType]
	wm title .editor "$upperType$lowerType Editor"

	slideGetParameters $nodeName $type
    } else {

	raise $notFrame
	wm title .editor "Editor"
	puts "$type Not implemented"
    }
}

proc Editor:LeftDown { } {
    global editorEntryHasFocus editorKeepFocus

    if { ($editorKeepFocus == 0) && ($editorEntryHasFocus == 1) } {

	Editor:EntryLooseFocus
    }

    set editorKeepFocus 0
}

proc Editor:EntryLooseFocus { } {
    global editorNameFrame 

    set results [Global:CheckSLIDEName]
    set type    [lindex $results 0]
    set i       [lindex $results 1]

    if { $type == "bad" } {
	
	# highlight incorrect name
	$editorNameFrame.name selection from $i
	$editorNameFrame.name selection adjust end
	
	.graph.canvas.entryName selection from $i
	return 
    }
    
    ########################################
    global editorEntryHasFocus 

    focus .editor
    $editorNameFrame.name selection clear
    set editorEntryHasFocus 0

    Graph:EntryHide
}

proc Editor:EntryHasFocus { w } {
    global graphEntryHasFocus editorEntryHasFocus editorKeepFocus 

    if { $graphEntryHasFocus == 0 } {
	global editNodeName

	set textId [.graph.canvas find withtag text[subst $editNodeName]]
	Graph:EntryShow $textId $editNodeName
    }

    set editorEntryHasFocus 1
    set editorKeepFocus     1
}

puts "loaded C:/Slide/lib/gui/editor/editor.tcl"
