# ------------------------------------------------------------------------------
#  Frame .editor.notebook.torus
#
#  Methods:
#     - TorusMenu:Create
#     - TorusMenu:Init
#     - TorusMenu:Adjust               = adjust the scale parameters based on value
#
#  Variables:
#     - torusGeomFrame
#     - torusOptionsFrame
#
#     - majorradius, minorradius, thetamax, thetaslices, phimin, phimax, phislices:
#             Value, Min, Max, AbsMin, AbsMax, Step, On, Help
#
#     - torusUndoList
#     - torusRedoList
#
# ------------------------------------------------------------------------------

proc TorusMenu:Create { torusFrame } {
    global torusGeomFrame torusOptionsFrame

    #########################################
    # Init
    TorusMenu:Init

    #########################################
    # Add Widgets to pages of notebook

    set torusGeomFrame [Notebook:frame $torusFrame Geometry]
    set parameters {majorradius minorradius thetamax thetaslices phimin phimax phislices}
    GeomMenu:CreateGeometry torus $torusGeomFrame $parameters

    set torusOptionsFrame [Notebook:frame $torusFrame Options]
    set options {surface shading lod solid}
    GeomMenu:CreateOptions $torusOptionsFrame $options
}

proc TorusMenu:Init { } {
    global torusUndoList torusRedoList

    set torusUndoList {}
    set torusRedoList {}

    global majorradiusValue majorradiusMin majorradiusMax majorradiusAbsMin \
	    majorradiusAbsMax majorradiusStep majorradiusOn majorradiusHelp \
	    torusmajorradiusSliderInit
    global minorradiusValue minorradiusMin minorradiusMax minorradiusAbsMin \
	    minorradiusAbsMax minorradiusStep minorradiusOn minorradiusHelp \
	    torusminorradiusSliderInit
    global thetamaxValue thetamaxMin thetamaxMax thetamaxAbsMin thetamaxAbsMax \
	    thetamaxStep thetamaxOn thetamaxHelp torusthetamaxSliderInit
    global thetaslicesValue thetaslicesMin thetaslicesMax thetaslicesHelp\
	    thetaslicesAbsMin thetaslicesAbsMax thetaslicesStep thetaslicesOn  \
	    torusthetaslicesSliderInit
    global phiminValue phiminMin phiminMax phiminAbsMin phiminAbsMax \
	    phiminStep phiminOn phiminHelp torusphiminSliderInit
    global phimaxValue phimaxMin phimaxMax phimaxAbsMin phimaxAbsMax \
	    phimaxStep phimaxOn phimaxHelp torusphimaxSliderInit
    global phislicesValue phislicesMin phislicesMax phislicesHelp\
	    phislicesAbsMin phislicesAbsMax phislicesStep phislicesOn  \
	    torusphislicesSliderInit


    global solidValue solidList solidHelp
    global shadingValue shadingList shadingHelp
    global lodValue lodList lodHelp

    global ribbeginValue ribbeginHelp
    global ribendValue ribendHelp
  
    set majorradiusValue   1.0
    set majorradiusMin     0.0
    set majorradiusMax    10.0
    set majorradiusAbsMin  0.0
    set majorradiusAbsMax 1000000.0
    set majorradiusStep    1.0
    set majorradiusOn 0
    set majorradiusHelp "major radius of the torus"
    set torusmajorradiusSliderInit 0

    set minorradiusValue   0.5
    set minorradiusMin     0.0
    set minorradiusMax    10.0
    set minorradiusAbsMin  0.0
    set minorradiusAbsMax 1000000.0
    set minorradiusStep    1.0
    set minorradiusOn 0
    set minorradiusHelp "minor radius of the torus"
    set torusminorradiusSliderInit 0
  
    set thetamaxValue   360
    set thetamaxMin    -360.0
    set thetamaxMax     360.0
    set thetamaxAbsMin -360.0
    set thetamaxAbsMax  360.0
    set thetamaxStep 1.0
    set thetamaxOn 0
    set thetamaxHelp "the cross-section cirlce begins at the x-axis and 
circles the z-axis by thetamax degrees"
    set torusthetamaxSliderInit 0

    set thetaslicesValue    8
    set thetaslicesMin      0
    set thetaslicesMax    100
    set thetaslicesAbsMin   0
    set thetaslicesAbsMax 1000000
    set thetaslicesStep 1
    set thetaslicesOn 0
    set thetaslicesHelp "number of triangle strips used to tesselate 
the torus in the radial direction"
    set torusthetaslicesSliderInit 0

    set phiminValue   0
    set phiminMin    -360.0
    set phiminMax     360.0
    set phiminAbsMin -360.0
    set phiminAbsMax  360.0
    set phiminStep 1.0
    set phiminOn 0
    set phiminHelp "the cross-section starts at phimin rotates 
and rotates phimax about the major radius circle."
    set torusphiminSliderInit 0

    set phimaxValue   360
    set phimaxMin    -360.0
    set phimaxMax     360.0
    set phimaxAbsMin -360.0
    set phimaxAbsMax  360.0
    set phimaxStep 1.0
    set phimaxOn 0
    set phimaxHelp "the cross-section circle starts at phimin 
and rotates phimax about the major radius circle."
    set torusphimaxSliderInit 0

    set phislicesValue    8
    set phislicesMin      0
    set phislicesMax    100
    set phislicesAbsMin   0
    set phislicesAbsMax 1000000
    set phislicesStep 1
    set phislicesOn 0
    set phislicesHelp "number of triangle strips used to tesselate
the cross-section circle"
    set torusphislicesSliderInit 0

    set solidValue solid
    set solidList {solid hollow}
    set solidHelp "This option determines whether backface culling is on or off:
   solid = enable backface culling
   hollow = disable backface culling"

    set shadingValue inherit
    set shadingList {inherit wire flat gouraud phong}
    set shadingHelp "This option defines how the polygons of the object are shaded:
   inherit = render in the same way as my parent
   wire = render a wireframe
   flat = render with flat shading 
   gouraud = render with Gouraud shading
   phong = render with Phong shading"

    set lodValue full
    set lodList {off bound edges full}
    set lodHelp "This option defines the quality of the rendering for this subtree:
   off = do not render
   bound = only render the bounding box
   edges = render in wireframe mode
   full = fully render"

    set ribbeginValue ""
    set ribbeginHelp "Renderman specific ASCII text that is written just 
before the primitive when outputting a RIB file"

    set ribendValue ""
    set ribendHelp "Renderman specific ASCII text that is written just 
after the primitive when outputting a RIB file"
}

