# Include the BWidget Library
if { [info sharedlibextension] == ".dll" } {
    # NT
    #lappend auto_path "S:\\slide\\lib\\slide\\BWidget-1.2.1\\"
    #lappend auto_path "C:\\Slide\\lib\\BWidget-1.2.1\\"

    set auto_path ""
	lappend auto_path "C:\\Slide\\lib\\BWidget-1.2.1\\"
    lappend auto_path "C:\\Slide\\lib\\Tcl8.0\\"
    lappend auto_path "C:\\Slide\\lib\\Tk8.0\\"
   
    if { [lsearch [array names env] SLIDE_LIBRARY] != -1 } {
	set auto_path [concat $env(SLIDE_LIBRARY) $auto_path]
    }
    set env(SYSTEM) NT    

    puts "auto_path = $auto_path"
} elseif { [info sharedlibextension] == ".so" } {
    # Unix
    lappend auto_path "/project/cs/sequin/caffe/slide/lib/slide/BWidget-1.2.1"
    if { [lsearch [array names env] SLIDE_LIBRARY] != -1 } {
	set auto_path [concat $env(SLIDE_LIBRARY) $auto_path]
    }
    set env(SYSTEM) [exec uname]
    if { $env(SYSTEM) == "IRIX64" } {
	set env(SYSTEM) "IRIX"
    }

    if { [lsearch {IRIX Linux} $env(SYSTEM)] == -1 } {
	puts "ERROR: Unsupported Unix platform \"$env(SYSTEM)\""
	exit
    }
} else {    
    puts "ERROR in main.tcl: SYSTEM not NT or IRIX"
    exit
}

package require BWidget
package provide mathlib 1.0

#########################################################################################
# Main Procedures

proc Main:SetBindings { w } {

    bind $w <Control-o> "Main:Open open"
    bind $w <Control-r> "Main:Open reload"
    bind $w <Control-m> "ToggleMode"
    bind $w <Control-s> "GUI:WriteSLIDE"
    
    bind $w <Control-t> "slideWriteDOT"
    bind $w <Control-b> "slideWriteRIB"

    bind $w <Control-l> "slideWriteSTL"
    bind $w <Control-f> "slideWriteSIF"
    bind $w <Escape>    "slideExit"
}

proc Main:New { } {

    slideNew
    Main:Opened
}

proc Main:Open { type } {

    slideOpen $type
}

proc Main:Close { } {

    slideClose

    .main.slide.menu entryconfigure "Reload"  -state disabled
    .main.slide.menu entryconfigure "Save"    -state disabled
    .main.slide.menu entryconfigure "Save As" -state disabled
    .main.slide.menu entryconfigure "Close"   -state disabled
}

proc Main:Opened { } {

    .main.slide.menu entryconfigure "Reload"  -state normal
    .main.slide.menu entryconfigure "Save"    -state normal
    .main.slide.menu entryconfigure "Save As" -state normal
    .main.slide.menu entryconfigure "Close"   -state normal
}

proc SetMode { mode } {
    global guiMode

    # This function is for SLIDE to call
    set guiMode $mode
}

proc ToggleMode { } {
    global guiMode

    if { $guiMode == "Viewer" } {
	set guiMode "Editor"
    } else {
	set guiMode "Viewer"
    }
    slideMode $guiMode
}

#########################################################################################
# Main Menu

frame .main

image create photo logo
logo configure -file "C:\\Slide\\lib\\slide.gif"
#logo configure -file "$SLF_LIBPATH/slide.gif"
#logo configure -file "/project/cs/sequin/caffe/slide/lib/slide/slide.gif"

set f {Helvetica 11 bold}

menubutton .main.slide -image logo -menu .main.slide.menu

set m1 [menu .main.slide.menu -tearoff 1]
$m1 add command -label "New"     -font $f -command "Main:New"
$m1 add command -label "Open"    -font $f -command "Main:Open open" \
	-underline 0 -accelerator "<Ctrl-o>"
$m1 add command -label "Reload"  -font $f -command "Main:Open reload" \
	-underline 0 -accelerator "<Ctrl-r>" -state disabled
$m1 add cascade -label "Mode"    -font $f -menu .main.slide.mode \
	-underline 0 -accelerator "<Ctrl-m>"

$m1 add separator
$m1 add command -label "Save"    -font $f -command "GUI:WriteSLIDE" \
	-underline 0 -accelerator "<Ctrl-s>" -state disabled
$m1 add cascade -label "Save As" -font $f -menu .main.slide.saveas -state disabled
$m1 add command -label "Help"    -font $f -command {puts "not implmented"}
$m1 add separator
$m1 add command -label "Close"   -font $f -command "Main:Close" -state disabled
$m1 add command -label "Exit"    -font $f -command "slideExit" \
	-underline 0 -accelerator "<Esc>"

set m2 [menu .main.slide.saveas -tearoff 1]
$m2 add command -label "DOT" -font $f -command "slideWriteDOT" \
	-underline 2 -accelerator "<Ctrl-t>"
$m2 add command -label "RIB" -font $f -command "slideWriteRIB" \
	-underline 2 -accelerator "<Ctrl-b>"
$m2 add command -label "STL" -font $f -command "slideWriteSTL" \
	-underline 2 -accelerator "<Ctrl-l>"
$m2 add command -label "SIF" -font $f -command "slideWriteSIF" \
	-underline 2 -accelerator "<Ctrl-f>"

set m3 [menu .main.slide.mode -tearoff 1]
$m3 add radio -label "Viewer" -font $f -variable guiMode -command "slideMode Viewer" 
$m3 add radio -label "Editor" -font $f -variable guiMode -command "slideMode Editor" 

pack .main.slide -side top -fill x
pack .main

wm title    . ""
wm geometry . +120+10
wm protocol . WM_DELETE_WINDOW {set foo 1}

##############################
# Set variables and bindings

global guiMode guiExists
set guiMode "Viewer"
set guiExists 0

slideMode $guiMode
Main:SetBindings .

.main.slide.menu entryconfigure "Help"  -state disabled

##########################################################################################

puts "loaded C:/Slide/lib/main.tcl"

